@@ -1,4 +1,4 @@
-package Catalyst::Authentication::Credential::HTTP; # git description: 1.016-6-g419d9af
+package Catalyst::Authentication::Credential::HTTP; # git description: v1.017-2-g36df161
 # ABSTRACT: HTTP Basic and Digest authentication for Catalyst
 
 use base qw/Catalyst::Authentication::Credential::Password/;
@@ -25,7 +25,7 @@ __PACKAGE__->mk_accessors(qw/
     broken_dotnet_digest_without_query_string
 /);
 
-our $VERSION = '1.017';
+our $VERSION = '1.018';
 
 sub new {
     my ($class, $config, $app, $realm) = @_;
@@ -411,7 +411,7 @@ Catalyst::Authentication::Credential::HTTP - HTTP Basic and Digest authenticatio
 
 =head1 VERSION
 
-version 1.017
+version 1.018
 
 =head1 SYNOPSIS
 
